@@ -319,7 +319,7 @@ void ViewMgrTest::testSplitView()
     QVERIFY(!frame2->isHidden());
 
     // Check container
-    QVERIFY(view->frame()->parentContainer()->frameType() == KonqFrameBase::Container);
+    QCOMPARE(view->frame()->parentContainer()->frameType(), KonqFrameBase::Container);
     KonqFrameContainer *container = static_cast<KonqFrameContainer *>(view->frame()->parentContainer());
     QVERIFY(container);
     QCOMPARE(container->count(), 2);
@@ -400,8 +400,8 @@ void ViewMgrTest::testSplitMainContainer()
     QVERIFY(!frame2->isHidden());
 
     // Check container
-    QVERIFY(view->frame()->parentContainer()->frameType() == KonqFrameBase::Tabs);
-    QVERIFY(view2->frame()->parentContainer()->frameType() == KonqFrameBase::Container);
+    QCOMPARE(view->frame()->parentContainer()->frameType(), KonqFrameBase::Tabs);
+    QCOMPARE(view2->frame()->parentContainer()->frameType(), KonqFrameBase::Container);
     KonqFrameContainer *container = static_cast<KonqFrameContainer *>(view2->frame()->parentContainer());
     QVERIFY(container);
     QCOMPARE(container->count(), 2);
@@ -600,7 +600,7 @@ static void openTabWithTitle(KonqMainWindow &mainWindow, const QString &title, K
     // correct since it's a subclass of text/html, khtml can display it
     QVERIFY(view->supportsMimeType("application/x-netscape-bookmarks"));
     // Tab caption test
-    view->openUrl(QUrl("data:text/html, <title>" + title.toUtf8() + "</title>"), QStringLiteral("http://loc.bar.url"));
+    view->openUrl(QUrl(QStringLiteral("data:text/html, <title>") + title + QStringLiteral("</title>")), QStringLiteral("http://loc.bar.url"));
     QSignalSpy spyCompleted(view, SIGNAL(viewCompleted(KonqView*)));
     QVERIFY(spyCompleted.wait(10000));
     QCOMPARE(view->caption(), title);
@@ -684,7 +684,7 @@ void ViewMgrTest::testDuplicateSplittedTab()
 
     KonqFrameContainer *container = static_cast<KonqFrameContainer *>(view->frame()->parentContainer());
     QVERIFY(container);
-    QVERIFY(container->parentContainer()->frameType() == KonqFrameBase::Tabs);
+    QCOMPARE(container->parentContainer()->frameType(), KonqFrameBase::Tabs);
 
     viewManager->duplicateTab(0); // TODO shouldn't it return a KonqFrameBase?
     QCOMPARE(DebugFrameVisitor::inspect(&mainWindow), QString("MT[C(FF)C(FF)]."));   // mainWindow, tab widget, two tabs
