@@ -22,7 +22,6 @@
 #include "autorefresh.h"
 #include <kparts/part.h>
 
-#include <kcomponentdata.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
 #include <KLocalizedString>
@@ -114,7 +113,7 @@ void AutoRefresh::slotRefresh()
         QString title = i18nc("@title:window", "Cannot Refresh Source");
         QString text = i18n("<qt>This plugin cannot auto-refresh the current part.</qt>");
 
-        KMessageBox::error(0, text, title);
+        KMessageBox::error(nullptr, text, title);
     } else {
         // Get URL
         QUrl url = part->url();
