@@ -12,28 +12,25 @@
  *  Library General Public License for more details.
  *
  *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  along with this program; see the file COPYING.  If not, see
+ *  <http://www.gnu.org/licenses/>.
  **/
 
-/* $Id$ */
-
-#ifndef plugin_webarchiver_h
-#define plugin_webarchiver_h
+#ifndef PLUGIN_WEBARCHIVER_H
+#define PLUGIN_WEBARCHIVER_H
 
 #include <kparts/plugin.h>
 
+
 class PluginWebArchiver : public KParts::Plugin
 {
     Q_OBJECT
 
 public:
-    PluginWebArchiver(QObject *parent,
-                      const QVariantList &);
-    ~PluginWebArchiver() override;
+    PluginWebArchiver(QObject *parent, const QVariantList &args);
+    ~PluginWebArchiver() override = default;
 
-public slots:
+protected slots:
     void slotSaveToArchive();
 };
 
