@@ -29,6 +29,7 @@
 #include "konqtabs.h"
 #include "konqhistorymanager.h"
 #include "konqpixmapprovider.h"
+#include "konqbrowserinterface.h"
 
 #include <kio/job.h>
 #include <kio/jobuidelegate.h>
@@ -36,16 +37,13 @@
 #include <kcursor.h>
 #include <kmessagebox.h>
 #include <KLocalizedString>
-#include <krandom.h>
 #include <ktoggleaction.h>
 #include <kjobuidelegate.h>
 #include <KUrlMimeData>
 
 #include <QApplication>
 #include <QArgument>
-#include <QObject>
 #include <QByteRef>
-#include <QEvent>
 #include <QFile>
 #include <QDropEvent>
 #include <QDBusConnection>
@@ -64,7 +62,6 @@
 #include <KParts/BrowserExtension>
 #include <KParts/WindowArgs>
 #include <QMimeDatabase>
-#include <QMimeType>
 
 //#define DEBUG_HISTORY
 
@@ -89,8 +86,6 @@ KonqView::KonqView(KonqViewFactory &viewFactory,
     m_pRun = nullptr;
     m_pPart = nullptr;
 
-    m_randID = KRandom::random();
-
     m_service = service;
     m_partServiceOffers = partServiceOffers;
     m_appServiceOffers = appServiceOffers;
@@ -251,6 +246,7 @@ void KonqView::switchView(KonqViewFactory &viewFactory)
     if (!part) {
         return;
     }
+    
     m_pPart = part;
 
     // Set the statusbar in the BE asap to avoid a KMainWindow statusbar being created.
@@ -386,6 +382,10 @@ void KonqView::connectPart()
     KParts::BrowserExtension *ext = browserExtension();
 
     if (ext) {
+        
+        KonqBrowserInterface *bi = new KonqBrowserInterface(mainWindow(), m_pPart);
+        ext->setBrowserInterface(bi);
+        
         connect(ext, SIGNAL(openUrlRequestDelayed(QUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)),
                 m_pMainWindow, SLOT(slotOpenURLRequest(QUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)));
 
@@ -1235,7 +1235,7 @@ bool KonqView::prepareReload(KParts::OpenUrlArguments &args, KParts::BrowserArgu
 
 KParts::BrowserExtension *KonqView::browserExtension() const
 {
-    return KParts::BrowserExtension::childObject(m_pPart);
+    return m_pPart ? KParts::BrowserExtension::childObject(m_pPart) : nullptr;
 }
 
 KParts::StatusBarExtension *KonqView::statusBarExtension() const
