@@ -1309,8 +1309,7 @@ void KonqViewManager::printSizeInfo(KonqFrameBase *frame,
                                     const char *msg)
 {
     const QRect r = frame->asQWidget()->geometry();
-    qDebug("Child size %s : x: %d, y: %d, w: %d, h: %d", msg, r.x(), r.y(), r.width(), r.height());
-
+    qCDebug(KONQUEROR_LOG) << "Child size" << msg << r;
     if (parent->frameType() == KonqFrameBase::Container) {
         const QList<int> sizes = static_cast<KonqFrameContainer *>(parent)->sizes();
         printf("Parent sizes %s :", msg);
@@ -1417,6 +1416,14 @@ bool KonqViewManager::isTabBarVisible() const
     return !m_tabContainer->tabBar()->isHidden();
 }
 
+void KonqViewManager::forceHideTabBar(bool force)
+{
+    if (m_tabContainer) {
+        m_tabContainer->forceHideTabBar(force);
+    }
+}
+
+
 void KonqViewManager::createTabContainer(QWidget *parent, KonqFrameContainerBase *parentContainer)
 {
 #ifdef DEBUG_VIEWMGR
