@@ -35,6 +35,18 @@
 #include <QFontDatabase>
 #include <QFileInfo>
 
+QDataStream & operator<<(QDataStream& ds, const WebEngineSettings::WebFormInfo& info)
+{
+    ds << info.name<< info.framePath << info.fields;
+    return ds;
+}
+
+QDataStream & operator>>(QDataStream& ds, WebEngineSettings::WebFormInfo& info)
+{
+    ds >> info.name >> info.framePath >> info.fields;
+    return ds;
+}
+
 /**
  * @internal
  * Contains all settings which are both available globally and per-domain
@@ -52,15 +64,15 @@ struct KPerDomainSettings {
 
 #ifdef DEBUG_SETTINGS
     void dump(const QString &infix = QString()) const {
-      kDebug() << "KPerDomainSettings " << infix << " @" << this << ":";
-      kDebug() << "  m_bEnableJava: " << m_bEnableJava;
-      kDebug() << "  m_bEnableJavaScript: " << m_bEnableJavaScript;
-      kDebug() << "  m_bEnablePlugins: " << m_bEnablePlugins;
-      kDebug() << "  m_windowOpenPolicy: " << m_windowOpenPolicy;
-      kDebug() << "  m_windowStatusPolicy: " << m_windowStatusPolicy;
-      kDebug() << "  m_windowFocusPolicy: " << m_windowFocusPolicy;
-      kDebug() << "  m_windowMovePolicy: " << m_windowMovePolicy;
-      kDebug() << "  m_windowResizePolicy: " << m_windowResizePolicy;
+      qCDebug(WEBENGINEPART_LOG) << "KPerDomainSettings " << infix << " @" << this << ":";
+      qCDebug(WEBENGINEPART_LOG) << "  m_bEnableJava: " << m_bEnableJava;
+      qCDebug(WEBENGINEPART_LOG) << "  m_bEnableJavaScript: " << m_bEnableJavaScript;
+      qCDebug(WEBENGINEPART_LOG) << "  m_bEnablePlugins: " << m_bEnablePlugins;
+      qCDebug(WEBENGINEPART_LOG) << "  m_windowOpenPolicy: " << m_windowOpenPolicy;
+      qCDebug(WEBENGINEPART_LOG) << "  m_windowStatusPolicy: " << m_windowStatusPolicy;
+      qCDebug(WEBENGINEPART_LOG) << "  m_windowFocusPolicy: " << m_windowFocusPolicy;
+      qCDebug(WEBENGINEPART_LOG) << "  m_windowMovePolicy: " << m_windowMovePolicy;
+      qCDebug(WEBENGINEPART_LOG) << "  m_windowResizePolicy: " << m_windowResizePolicy;
     }
 #endif
 };
@@ -131,6 +143,7 @@ public:
     QList< QPair< QString, QChar > > m_fallbackAccessKeysAssignments;
 
     KSharedConfig::Ptr nonPasswordStorableSites;
+    KSharedConfig::Ptr sitesWithCustomForms;
     bool m_internalPdfViewer;
 };
 
@@ -146,7 +159,7 @@ public:
             QTextStream ts(&file);
             QString line = ts.readLine();
             while (!line.isEmpty()) {
-                //kDebug() << "Adding filter:" << line;
+                //qCDebug(WEBENGINEPART_LOG) << "Adding filter:" << line;
                 /** white list lines start with "@@" */
                 if (line.startsWith(QLatin1String("@@")))
                     adWhiteList.addFilter(line);
@@ -387,9 +400,9 @@ void WebEngineSettings::init( KConfig * config, bool reset )
                   if (!fileInfo.exists() || fileInfo.lastModified().daysTo(QDateTime::currentDateTime()) > htmlFilterListMaxAgeDays)
                   {
                       /** ... in this case, refetch list asynchronously */
-                      // kDebug() << "Fetching filter list from" << url << "to" << localFile;
+                      // qCDebug(WEBENGINEPART_LOG) << "Fetching filter list from" << url << "to" << localFile;
                       KIO::StoredTransferJob *job = KIO::storedGet( url, KIO::Reload, KIO::HideProgressInfo );
-                      QObject::connect( job, SIGNAL(result(KJob*)), d, SLOT(adblockFilterResult(KJob*)) );
+                      QObject::connect( job, &KJob::result, d, &WebEngineSettingsPrivate::adblockFilterResult);
                       /** for later reference, store name of cache file */
                       job->setProperty("webenginesettings_adBlock_filename", localFile);
                   }
@@ -720,6 +733,8 @@ void WebEngineSettings::init( KConfig * config, bool reset )
   QWebEngineSettings::defaultSettings()->setAttribute(QWebEngineSettings::PdfViewerEnabled, internalPdfViewer());
 #endif
 
+  QWebEngineSettings::defaultSettings()->setAttribute(QWebEngineSettings::FullScreenSupportEnabled, true);
+
   // These numbers should be calculated from real "logical" DPI/72, using a default dpi of 96 for now
   computeFontSizes(96);
 }
@@ -761,7 +776,7 @@ static const KPerDomainSettings& lookup_hostname_policy(const WebEngineSettingsP
                                                         const QString& hostname)
 {
 #ifdef DEBUG_SETTINGS
-  kDebug() << "lookup_hostname_policy(" << hostname << ")";
+  qCDebug(WEBENGINEPART_LOG) << "lookup_hostname_policy(" << hostname << ")";
 #endif
   if (hostname.isEmpty()) {
 #ifdef DEBUG_SETTINGS
@@ -776,7 +791,7 @@ static const KPerDomainSettings& lookup_hostname_policy(const WebEngineSettingsP
   PolicyMap::const_iterator it = d->domainPolicy.find(hostname);
   if( it != notfound ) {
 #ifdef DEBUG_SETTINGS
-    kDebug() << "perfect match";
+    qCDebug(WEBENGINEPART_LOG) << "perfect match";
     (*it).dump(hostname);
 #endif
     // yes, use it (unless dunno)
@@ -793,7 +808,7 @@ static const KPerDomainSettings& lookup_hostname_policy(const WebEngineSettingsP
     Q_ASSERT(notfound == d->domainPolicy.end());
     if( it != notfound ) {
 #ifdef DEBUG_SETTINGS
-      kDebug() << "partial match";
+      qCDebug(WEBENGINEPART_LOG) << "partial match";
       (*it).dump(host_part);
 #endif
       return *it;
@@ -804,7 +819,7 @@ static const KPerDomainSettings& lookup_hostname_policy(const WebEngineSettingsP
 
   // No domain-specific entry: use global domain
 #ifdef DEBUG_SETTINGS
-  kDebug() << "no match";
+  qCDebug(WEBENGINEPART_LOG) << "no match";
   d->global.dump("global");
 #endif
   return d->global;
@@ -1183,27 +1198,25 @@ bool WebEngineSettings::acceptCrossDomainCookies() const
     return d->m_acceptCrossDomainCookies;
 }
 
-
 // Password storage...
-static KConfigGroup nonPasswordStorableSitesCg(KSharedConfig::Ptr& configPtr)
+KConfigGroup WebEngineSettings::nonPasswordStorableSitesCg() const
 {
-    if (!configPtr) {
-        configPtr = KSharedConfig::openConfig(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("khtml/formcompletions")), KConfig::NoGlobals);
+    if (!d->nonPasswordStorableSites) {
+        d->nonPasswordStorableSites = KSharedConfig::openConfig(QString(), KConfig::NoGlobals);
     }
-
-    return KConfigGroup(configPtr, "NonPasswordStorableSites");
+    return KConfigGroup(d->nonPasswordStorableSites, "NonPasswordStorableSites");
 }
 
 bool WebEngineSettings::isNonPasswordStorableSite(const QString &host) const
 {
-    KConfigGroup cg = nonPasswordStorableSitesCg(d->nonPasswordStorableSites);
+    KConfigGroup cg = nonPasswordStorableSitesCg();
     const QStringList sites = cg.readEntry("Sites", QStringList());
     return sites.contains(host);
 }
 
 void WebEngineSettings::addNonPasswordStorableSite(const QString &host)
 {
-    KConfigGroup cg = nonPasswordStorableSitesCg(d->nonPasswordStorableSites);
+    KConfigGroup cg = nonPasswordStorableSitesCg();
     QStringList sites = cg.readEntry("Sites", QStringList());
     sites.append(host);
     cg.writeEntry("Sites", sites);
@@ -1212,13 +1225,57 @@ void WebEngineSettings::addNonPasswordStorableSite(const QString &host)
 
 void WebEngineSettings::removeNonPasswordStorableSite(const QString &host)
 {
-    KConfigGroup cg = nonPasswordStorableSitesCg(d->nonPasswordStorableSites);
+    KConfigGroup cg = nonPasswordStorableSitesCg();
     QStringList sites = cg.readEntry("Sites", QStringList());
     sites.removeOne(host);
     cg.writeEntry("Sites", sites);
     cg.sync();
 }
 
+KConfigGroup WebEngineSettings::pagesWithCustomizedCacheableFieldsCg() const
+{
+    if (!d->sitesWithCustomForms) {
+        d->sitesWithCustomForms = KSharedConfig::openConfig(QString(), KConfig::NoGlobals); 
+    }
+    return KConfigGroup(d->sitesWithCustomForms, "PagesWithCustomizedCacheableFields");
+}
+
+void WebEngineSettings::setCustomizedCacheableFieldsForPage(const QString& url, const WebFormInfoList& forms)
+{
+    KConfigGroup cg = pagesWithCustomizedCacheableFieldsCg();
+    QByteArray data;
+    QDataStream ds(&data, QIODevice::WriteOnly);
+    ds << forms;
+    cg.writeEntry(url, data);
+    cg.sync();
+}
+
+bool WebEngineSettings::hasPageCustomizedCacheableFields(const QString& url) const
+{
+    KConfigGroup cg = pagesWithCustomizedCacheableFieldsCg();
+    return cg.hasKey(url);
+}
+
+void WebEngineSettings::removeCacheableFieldsCustomizationForPage(const QString& url)
+{
+    KConfigGroup cg = pagesWithCustomizedCacheableFieldsCg();
+    cg.deleteEntry(url);
+    cg.sync();
+}
+
+WebEngineSettings::WebFormInfoList WebEngineSettings::customizedCacheableFieldsForPage(const QString& url)
+{
+    KConfigGroup cg = pagesWithCustomizedCacheableFieldsCg();
+    QByteArray data = cg.readEntry(url, QByteArray());
+    if (data.isEmpty()) {
+        return {};
+    }
+    QDataStream ds(data);
+    WebFormInfoList res;
+    ds >> res;
+    return res;
+}
+
 bool WebEngineSettings::askToSaveSitePassword() const
 {
     return d->m_offerToSaveWebSitePassword;
@@ -1283,4 +1340,12 @@ WebEngineSettings* WebEngineSettings::self()
     return &s_webEngineSettings;
 }
 
+QDebug operator<<(QDebug dbg, const WebEngineSettings::WebFormInfo& info)
+{
+    QDebugStateSaver state(dbg);
+    dbg.nospace() << "CustomWebFormInfo{";
+    dbg << info.name << ", " << info.framePath << ", " << info.fields << "}";
+    return dbg;
+}
+
 #include "webenginesettings.moc"
