@@ -23,7 +23,6 @@
 #include "webenginepage.h"
 
 #include "webenginepart.h"
-#include "websslinfo.h"
 #include "webengineview.h"
 #include "settings/webenginesettings.h"
 #include "webenginepartdownloadmanager.h"
@@ -50,6 +49,7 @@
 #include <KParts/HtmlExtension>
 #include <KUserTimestamp>
 #include <KPasswdServerClient>
+#include <KParts/BrowserInterface>
 
 #include <QStandardPaths>
 #include <QDesktopWidget>
@@ -64,6 +64,7 @@
 #include <QWebEngineDownloadItem>
 #include <QUrlQuery>
 #include <KConfigGroup>
+#include <KToggleFullScreenAction>
 //#include <QWebSecurityOrigin>
 #include "utils.h"
 
@@ -91,6 +92,7 @@ WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
             this, &WebEnginePage::slotLoadFinished);
     connect(this, &QWebEnginePage::authenticationRequired,
             this, &WebEnginePage::slotAuthenticationRequired);
+    connect(this, &QWebEnginePage::fullScreenRequested, this, &WebEnginePage::changeFullScreenMode);
     if(!this->profile()->httpUserAgent().contains(QLatin1String("Konqueror")))
     {
         this->profile()->setHttpUserAgent(this->profile()->httpUserAgent() + " Konqueror (WebEnginePart)");
@@ -103,7 +105,7 @@ WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
 
 WebEnginePage::~WebEnginePage()
 {
-    //kDebug() << this;
+    //qCDebug(WEBENGINEPART_LOG) << this;
 }
 
 const WebSslInfo& WebEnginePage::sslInfo() const
@@ -137,14 +139,14 @@ static void checkForDownloadManager(QWidget* widget, QString& cmd)
     cmd = exeName;
 }
 
-void WebEnginePage::download(const QUrl& url, bool newWindow)
+void WebEnginePage::download(const QUrl& url, const QString& mimetype, bool newWindow)
 {
     // Integration with a download manager...
     if (!url.isLocalFile()) {
         QString managerExe;
         checkForDownloadManager(view(), managerExe);
         if (!managerExe.isEmpty()) {
-            //qDebug() << "Calling command" << cmd;
+            //qCDebug(WEBENGINEPART_LOG) << "Calling command" << cmd;
             KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(managerExe, {url.toString()});
             job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, view()));
             job->start();
@@ -153,7 +155,19 @@ void WebEnginePage::download(const QUrl& url, bool newWindow)
     }
     KParts::BrowserArguments bArgs;
     bArgs.setForcesNewWindow(newWindow);
-    emit part()->browserExtension()->openUrlRequest(url, KParts::OpenUrlArguments(), bArgs);
+    KParts::OpenUrlArguments urlArgs;
+    urlArgs.setMimeType(mimetype);
+    emit part()->browserExtension()->openUrlRequest(url, urlArgs, bArgs);
+}
+
+void WebEnginePage::requestOpenFileAsTemporary(const QUrl& url, const QString &mimeType, bool newWindow)
+{
+    KParts::BrowserArguments bArgs;
+    bArgs.setForcesNewWindow(newWindow);
+    KParts::OpenUrlArguments oArgs;
+    oArgs.setMimeType(mimeType);
+    oArgs.metaData().insert("konq-temp-file", "1");
+    emit part()->browserExtension()->openUrlRequest(url, oArgs, bArgs);
 }
 
 QWebEnginePage *WebEnginePage::createWindow(WebWindowType type)
@@ -172,8 +186,16 @@ static bool domainSchemeMatch(const QUrl& u1, const QUrl& u2)
     if (u1.scheme() != u2.scheme())
         return false;
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QStringList u1List = u1.host().split(QL1C('.'), QString::SkipEmptyParts);
+#else
+    QStringList u1List = u1.host().split(QL1C('.'), Qt::SkipEmptyParts);
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QStringList u2List = u2.host().split(QL1C('.'), QString::SkipEmptyParts);
+#else
+    QStringList u2List = u2.host().split(QL1C('.'), Qt::SkipEmptyParts);
+#endif
 
     if (qMin(u1List.count(), u2List.count()) < 2)
         return false;  // better safe than sorry...
@@ -224,7 +246,10 @@ bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type
         case QWebEnginePage::NavigationTypeFormSubmitted:
             if (!checkFormData(url))
                return false;
-            m_wallet->saveFormData(this);
+            if (m_wallet) {
+                m_wallet->saveFormsInPage(this);
+            }
+
             break;
 #if 0
         case QWebEnginePage::NavigationTypeFormResubmitted:
@@ -250,7 +275,7 @@ bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type
                 qCDebug(WEBENGINEPART_LOG) << "Rejected history navigation because 'HistoryNavigationLocked' property is set!";
                 return false;
             }
-            //kDebug() << "Navigating to item (" << history()->currentItemIndex()
+            //qCDebug(WEBENGINEPART_LOG) << "Navigating to item (" << history()->currentItemIndex()
             //         << "of" << history()->count() << "):" << history()->currentItem().url();
             inPageRequest = false;
             break;
@@ -277,9 +302,7 @@ bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type
 
     // Honor the enabling/disabling of plugins per host.
     settings()->setAttribute(QWebEngineSettings::PluginsEnabled, WebEngineSettings::self()->isPluginsEnabled(reqUrl.host()));
-#ifndef DOWNLOADITEM_KNOWS_PAGE
-    emit navigationRequested(this, url);
-#endif
+
     return QWebEnginePage::acceptNavigationRequest(url, type, isMainFrame);
 }
 
@@ -328,10 +351,7 @@ static int errorCodeFromReply(QNetworkReply* reply)
 
 bool WebEnginePage::certificateError(const QWebEngineCertificateError& ce)
 {
-    if (m_urlLoadedByPart == ce.url()) {
-        m_urlLoadedByPart = QUrl();
-        return true;
-    } else if (ce.isOverridable()) {
+    if (ce.isOverridable()) {
         QString translatedDesc = i18n(ce.errorDescription().toUtf8());
         QString text = i18n("<p>The server failed the authenticity check (%1). The error is:</p><p><tt>%2</tt></p>Do you want to ignore this error?",
                             ce.url().host(), translatedDesc);
@@ -356,8 +376,8 @@ void WebEnginePage::slotLoadFinished(bool ok)
 {
     QUrl requestUrl = url();
     requestUrl.setUserInfo(QString());
-    const bool shouldResetSslInfo = (m_sslInfo.isValid() && !domainSchemeMatch(requestUrl, m_sslInfo.url()));
 #if 0
+    const bool shouldResetSslInfo = (m_sslInfo.isValid() && !domainSchemeMatch(requestUrl, m_sslInfo.url()));
     QWebFrame* frame = qobject_cast<QWebFrame *>(reply->request().originatingObject());
     if (!frame)
         return;
@@ -378,7 +398,7 @@ void WebEnginePage::slotLoadFinished(bool ok)
     }
 
     const int errCode = errorCodeFromReply(reply);
-    kDebug() << frame << "is main frame request?" << isMainFrameRequest << requestUrl;
+    qCDebug(WEBENGINEPART_LOG) << frame << "is main frame request?" << isMainFrameRequest << requestUrl;
 #endif
 
     if (ok) {
@@ -398,7 +418,7 @@ void WebEnginePage::slotLoadFinished(bool ok)
             break;
         case KIO::ERR_ABORTED:
         case KIO::ERR_USER_CANCELED: // Do nothing if request is cancelled/aborted
-            //kDebug() << "User aborted request!";
+            //qCDebug(WEBENGINEPART_LOG) << "User aborted request!";
             m_ignoreError = true;
             emit loadAborted(QUrl());
             return;
@@ -429,7 +449,7 @@ void WebEnginePage::slotLoadFinished(bool ok)
 void WebEnginePage::slotUnsupportedContent(QNetworkReply* reply)
 {
 #if 0
-    //kDebug() << reply->url();
+    //qCDebug(WEBENGINEPART_LOG) << reply->url();
     QString mimeType;
     KIO::MetaData metaData;
 
@@ -453,7 +473,7 @@ void WebEnginePage::slotUnsupportedContent(QNetworkReply* reply)
         return;
     }
 
-    //kDebug() << "mimetype=" << mimeType << "metadata:" << metaData;
+    //qCDebug(WEBENGINEPART_LOG) << "mimetype=" << mimeType << "metadata:" << metaData;
 
     if (reply->request().originatingObject() == this->mainFrame()) {
         KParts::OpenUrlArguments args;
@@ -468,8 +488,11 @@ void WebEnginePage::slotUnsupportedContent(QNetworkReply* reply)
 }
 void WebEnginePage::slotFeaturePermissionRequested(const QUrl& url, QWebEnginePage::Feature feature)
 {
-    if (url == this->url()) {
-        part()->slotShowFeaturePermissionBar(feature);
+    //url.path() is always / (meaning that permissions should be granted site-wide and not per page)
+    QUrl thisUrl(this->url());
+    thisUrl.setPath("/");
+    if (url == thisUrl) {
+        part()->slotShowFeaturePermissionBar(url, feature);
         return;
     }
     switch(feature) {
@@ -528,7 +551,7 @@ void WebEnginePage::slotGeometryChangeRequested(const QRect & rect)
     }
 
     if (WebEngineSettings::self()->windowResizePolicy(host) == KParts::HtmlSettingsInterface::JSWindowResizeAllow) {
-        //kDebug() << "resizing to " << width << "x" << height;
+        //qCDebug(WEBENGINEPART_LOG) << "resizing to " << width << "x" << height;
         emit m_part->browserExtension()->resizeTopLevelWidget(width, height);
     }
 
@@ -551,7 +574,7 @@ bool WebEnginePage::checkLinkSecurity(const QNetworkRequest &req, NavigationType
     // Check whether the request is authorized or not...
     if (!KUrlAuthorized::authorizeUrlAction(QStringLiteral("redirect"), url(), req.url())) {
 
-        //kDebug() << "*** Failed security check: base-url=" << mainFrame()->url() << ", dest-url=" << req.url();
+        //qCDebug(WEBENGINEPART_LOG) << "*** Failed security check: base-url=" << mainFrame()->url() << ", dest-url=" << req.url();
         QString buttonText, title, message;
 
         int response = KMessageBox::Cancel;
@@ -688,7 +711,7 @@ bool WebEnginePage::handleMailToUrl (const QUrl &url, NavigationType type) const
                  break;
         }
 
-        //kDebug() << "Emitting openUrlRequest with " << mailtoUrl;
+        //qCDebug(WEBENGINEPART_LOG) << "Emitting openUrlRequest with " << mailtoUrl;
         emit m_part->browserExtension()->openUrlRequest(mailtoUrl);
         return true;
     }
@@ -729,8 +752,25 @@ void WebEnginePage::slotAuthenticationRequired(const QUrl &requestUrl, QAuthenti
     }
 }
 
+void WebEnginePage::changeFullScreenMode(QWebEngineFullScreenRequest req)
+{
+        KParts::BrowserInterface *iface = part()->browserExtension()->browserInterface();
+        if (iface) {
+            req.accept();
+            iface->callMethod("toggleCompleteFullScreen", req.toggleOn());
+        } else {
+            req.reject();
+        }
+}
 
 
+void WebEnginePage::setStatusBarText(const QString& text)
+{
+    if (m_part) {
+        emit m_part->setStatusBarText(text);
+    }
+}
+
 /************************************* Begin NewWindowPage ******************************************/
 
 NewWindowPage::NewWindowPage(WebWindowType type, WebEnginePart* part, QWidget* parent)
@@ -738,18 +778,17 @@ NewWindowPage::NewWindowPage(WebWindowType type, WebEnginePart* part, QWidget* p
 {
     Q_ASSERT_X (part, "NewWindowPage", "Must specify a valid KPart");
 
+    // FIXME: are these 3 signals actually defined or used?
     connect(this, SIGNAL(menuBarVisibilityChangeRequested(bool)),
             this, SLOT(slotMenuBarVisibilityChangeRequested(bool)));
     connect(this, SIGNAL(toolBarVisibilityChangeRequested(bool)),
             this, SLOT(slotToolBarVisibilityChangeRequested(bool)));
     connect(this, SIGNAL(statusBarVisibilityChangeRequested(bool)),
             this, SLOT(slotStatusBarVisibilityChangeRequested(bool)));
-    connect(this, SIGNAL(loadFinished(bool)), this, SLOT(slotLoadFinished(bool)));
-#if QTWEBENGINE_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+    connect(this, &QWebEnginePage::loadFinished, this, &NewWindowPage::slotLoadFinished);
     if (m_type == WebBrowserBackgroundTab) {
         m_windowArgs.setLowerWindow(true);
     }
-#endif
 }
 
 NewWindowPage::~NewWindowPage()
@@ -765,9 +804,7 @@ static KParts::BrowserArguments browserArgs(WebEnginePage::WebWindowType type)
             bargs.setForcesNewWindow(true);
             break;
         case WebEnginePage::WebBrowserTab:
-#if QTWEBENGINE_VERSION >= QT_VERSION_CHECK(5, 7, 0)
         case WebEnginePage::WebBrowserBackgroundTab:
-#endif
             // let konq decide, based on user configuration
             //bargs.setNewTab(true);
             break;
@@ -864,9 +901,6 @@ bool NewWindowPage::acceptNavigationRequest(const QUrl &url, NavigationType type
 
     }
 
-#ifndef DOWNLOADITEM_KNOWS_PAGE
-    emit navigationRequested(this, url);
-#endif
     return WebEnginePage::acceptNavigationRequest(url, type, isMainFrame);
 }
 
@@ -888,19 +922,19 @@ void NewWindowPage::slotGeometryChangeRequested(const QRect & rect)
 
 void NewWindowPage::slotMenuBarVisibilityChangeRequested(bool visible)
 {
-    //kDebug() << visible;
+    //qCDebug(WEBENGINEPART_LOG) << visible;
     m_windowArgs.setMenuBarVisible(visible);
 }
 
 void NewWindowPage::slotStatusBarVisibilityChangeRequested(bool visible)
 {
-    //kDebug() << visible;
+    //qCDebug(WEBENGINEPART_LOG) << visible;
     m_windowArgs.setStatusBarVisible(visible);
 }
 
 void NewWindowPage::slotToolBarVisibilityChangeRequested(bool visible)
 {
-    //kDebug() << visible;
+    //qCDebug(WEBENGINEPART_LOG) << visible;
     m_windowArgs.setToolBarsVisible(visible);
 }
 
