@@ -46,6 +46,7 @@
 #include "ui/passwordbar.h"
 #include "ui/featurepermissionbar.h"
 #include "settings/webenginesettings.h"
+#include "ui/credentialsdetailswidget.h"
 
 #include <KCodecAction>
 #include <KIO/Global>
@@ -55,7 +56,6 @@
 #include <KUrlLabel>
 #include <KMessageBox>
 #include <KStringHandler>
-#include <KToolInvocation>
 #include <KAcceleratorManager>
 #include <KFileItem>
 #include <KMessageWidget>
@@ -69,8 +69,10 @@
 #include <KSslInfoDialog>
 #include <KProtocolManager>
 #include <KProtocolInfo>
+#include <KParts/PartActivateEvent>
+#include <KParts/BrowserInterface>
+#include <KIO/ApplicationLauncherJob>
 
-#include <QUrl>
 #include <QFile>
 #include <QTextCodec>
 #include <QCoreApplication>
@@ -78,33 +80,22 @@
 #include <QDBusInterface>
 #include <QMenu>
 #include <QStatusBar>
-#ifdef USE_QWEBENGINE_URL_SCHEME
+#include <QWebEngineScriptCollection>
 #include <QWebEngineUrlScheme>
-#endif
 #include "utils.h"
 #include <kio_version.h>
 
 void WebEnginePart::initWebEngineUrlSchemes()
 {
-#ifdef USE_QWEBENGINE_URL_SCHEME
     static bool needToInitUrlSchemes = true;
     if (needToInitUrlSchemes) {
         needToInitUrlSchemes = false;
         QVector<QByteArray> localSchemes = {"error", "konq"};
         const QStringList protocols = KProtocolInfo::protocols();
         for(const QString &prot : protocols){
-#if KIO_VERSION >= QT_VERSION_CHECK(5,60,0)
             if (KProtocolInfo::defaultMimetype(prot) == "text/html") {
                 localSchemes.append(QByteArray(prot.toLatin1()));
             }
-#else
-            QUrl fakeUrl;
-            fakeUrl.setScheme(prot);
-            fakeUrl.setPath("fake");
-            if (KProtocolManager::defaultMimetype(fakeUrl) == "text/html"){
-                localSchemes.append(QByteArray(prot.toLatin1()));
-            }
-#endif
         }
         for (const QByteArray &name : qAsConst(localSchemes)){
             QWebEngineUrlScheme scheme(name);
@@ -113,19 +104,17 @@ void WebEnginePart::initWebEngineUrlSchemes()
             QWebEngineUrlScheme::registerScheme(scheme);
         }
     }
-#endif
 }
 
 WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
                          const QByteArray& cachedHistory, const QStringList& /*args*/)
             :KParts::ReadOnlyPart(parent),
              m_emitOpenUrlNotify(true),
-             m_hasCachedFormData(false),
+             m_walletData{false, false, false},
              m_doLoadFinishedActions(false),
              m_statusBarWalletLabel(nullptr),
              m_searchBar(nullptr),
              m_passwordBar(nullptr),
-             m_featurePermissionBar(nullptr),
              m_wallet(nullptr)
 {
     initWebEngineUrlSchemes();
@@ -223,6 +212,9 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
     // Load plugins once we are fully ready
     loadPlugins();
     setWallet(page()->wallet());
+    if (m_wallet) {
+        page()->scripts().insert(WebEngineWallet::formDetectorFunctionsScript());
+    }
 }
 
 WebEnginePart::~WebEnginePart()
@@ -245,8 +237,8 @@ const WebEnginePage* WebEnginePart::page() const
 
 void WebEnginePart::initActions()
 {
-    actionCollection()->addAction(KStandardAction::SaveAs, QStringLiteral("saveDocument"),
-                                  m_browserExtension, SLOT(slotSaveDocument()));
+    KStandardAction::create(KStandardAction::SaveAs, m_browserExtension, &WebEngineBrowserExtension::slotSaveDocument,
+                            actionCollection());
 
     QAction* action = new QAction(i18n("Save &Frame As..."), this);
     actionCollection()->addAction(QStringLiteral("saveFrame"), action);
@@ -286,14 +278,15 @@ void WebEnginePart::initActions()
     actionCollection()->addAction(QStringLiteral("zoomToDPI"), action);
     connect(action, &QAction::triggered, m_browserExtension, &WebEngineBrowserExtension::toogleZoomToDPI);
 
-    action = actionCollection()->addAction(KStandardAction::SelectAll, QStringLiteral("selectAll"),
-                                           m_browserExtension, SLOT(slotSelectAll()));
+
+    action = KStandardAction::create(KStandardAction::SelectAll, m_browserExtension, &WebEngineBrowserExtension::slotSelectAll,
+                                     actionCollection());
     action->setShortcutContext(Qt::WidgetShortcut);
     m_webView->addAction(action);
 
     KCodecAction *codecAction = new KCodecAction( QIcon::fromTheme(QStringLiteral("character-set")), i18n( "Set &Encoding" ), this, true );
     actionCollection()->addAction( QStringLiteral("setEncoding"), codecAction );
-    connect(codecAction, SIGNAL(triggered(QTextCodec*)), SLOT(slotSetTextEncoding(QTextCodec*)));
+    connect(codecAction, QOverload<QTextCodec *>::of(&KCodecAction::triggered), this, &WebEnginePart::slotSetTextEncoding);
 
     action = new QAction(i18n("View Do&cument Source"), this);
     actionCollection()->addAction(QStringLiteral("viewDocumentSource"), action);
@@ -304,9 +297,12 @@ void WebEnginePart::initActions()
     actionCollection()->addAction(QStringLiteral("security"), action);
     connect(action, &QAction::triggered, this, &WebEnginePart::slotShowSecurity);
 
-    action = actionCollection()->addAction(KStandardAction::Find, QStringLiteral("find"), this, SLOT(slotShowSearchBar()));
+    action = KStandardAction::create(KStandardAction::Find, this,
+                                     &WebEnginePart::slotShowSearchBar, actionCollection());
     action->setWhatsThis(i18nc("find action \"whats this\" text", "<h3>Find text</h3>"
                               "Shows a dialog that allows you to find text on the displayed page."));
+
+    createWalletActions();
 }
 
 void WebEnginePart::updateActions()
@@ -331,20 +327,16 @@ void WebEnginePart::connectWebEnginePageSignals(WebEnginePage* page)
     if (!page)
         return;
 
-    connect(page, SIGNAL(loadStarted()),
-            this, SLOT(slotLoadStarted()));
-    connect(page, SIGNAL(loadAborted(QUrl)),
-            this, SLOT(slotLoadAborted(QUrl)));
-    connect(page, &QWebEnginePage::linkHovered,
-            this, &WebEnginePart::slotLinkHovered);
+    connect(page, &QWebEnginePage::loadStarted, this, &WebEnginePart::slotLoadStarted);
+    connect(page, &WebEnginePage::loadAborted, this, &WebEnginePart::slotLoadAborted);
+    connect(page, &QWebEnginePage::linkHovered, this, &WebEnginePart::slotLinkHovered);
 //    connect(page, SIGNAL(saveFrameStateRequested(QWebFrame*,QWebHistoryItem*)),
 //            this, SLOT(slotSaveFrameState(QWebFrame*,QWebHistoryItem*)));
 //    connect(page, SIGNAL(restoreFrameStateRequested(QWebFrame*)),
 //            this, SLOT(slotRestoreFrameState(QWebFrame*)));
 //    connect(page, SIGNAL(statusBarMessage(QString)),
 //            this, SLOT(slotSetStatusBarText(QString)));
-    connect(page, SIGNAL(windowCloseRequested()),
-            this, SLOT(slotWindowCloseRequested()));
+    connect(page, &QWebEnginePage::windowCloseRequested, this, &WebEnginePart::slotWindowCloseRequested);
 //    connect(page, SIGNAL(printRequested(QWebFrame*)),
 //            m_browserExtension, SLOT(slotPrintRequested(QWebFrame*)));
  //   connect(page, SIGNAL(frameCreated(QWebFrame*)),
@@ -353,10 +345,8 @@ void WebEnginePart::connectWebEnginePageSignals(WebEnginePage* page)
 //    connect(m_webView, SIGNAL(linkShiftClicked(QUrl)),
 //            page, SLOT(downloadUrl(QUrl)));
 
-    connect(page, SIGNAL(loadProgress(int)),
-            m_browserExtension, SIGNAL(loadingProgress(int)));
-    connect(page, SIGNAL(selectionChanged()),
-            m_browserExtension, SLOT(updateEditActions()));
+    connect(page, &QWebEnginePage::loadProgress, m_browserExtension, &KParts::BrowserExtension::loadingProgress);
+    connect(page, &QWebEnginePage::selectionChanged, m_browserExtension, &WebEngineBrowserExtension::updateEditActions);
 //    connect(m_browserExtension, SIGNAL(saveUrl(QUrl)),
 //            page, SLOT(downloadUrl(QUrl)));
 
@@ -375,7 +365,10 @@ void WebEnginePart::setWallet(WebEngineWallet* wallet)
                 this, &WebEnginePart::slotSaveFormDataRequested);
         disconnect(m_wallet, &WebEngineWallet::fillFormRequestCompleted,
                 this, &WebEnginePart::slotFillFormRequestCompleted);
-        disconnect(m_wallet, &WebEngineWallet::walletClosed, this, &WebEnginePart::slotWalletClosed);
+        disconnect(m_wallet, &WebEngineWallet::walletClosed, this, &WebEnginePart::resetWallet);
+        disconnect(m_wallet, &WebEngineWallet::formDetectionDone, this, &WebEnginePart::walletFinishedFormDetection);
+        disconnect(m_wallet, &WebEngineWallet::saveFormDataCompleted, this, &WebEnginePart::slotWalletSavedForms);
+        disconnect(m_wallet, &WebEngineWallet::walletOpened, this, &WebEnginePart::updateWalletActions);
     }
     m_wallet = wallet;
     if (m_wallet) {
@@ -383,7 +376,10 @@ void WebEnginePart::setWallet(WebEngineWallet* wallet)
                 this, &WebEnginePart::slotSaveFormDataRequested);
         connect(m_wallet, &WebEngineWallet::fillFormRequestCompleted,
                 this, &WebEnginePart::slotFillFormRequestCompleted);
-        connect(m_wallet, &WebEngineWallet::walletClosed, this, &WebEnginePart::slotWalletClosed);
+        connect(m_wallet, &WebEngineWallet::walletClosed, this, &WebEnginePart::resetWallet);
+        connect(m_wallet, &WebEngineWallet::formDetectionDone, this, &WebEnginePart::walletFinishedFormDetection);
+        connect(m_wallet, &WebEngineWallet::saveFormDataCompleted, this, &WebEnginePart::slotWalletSavedForms);
+        connect(m_wallet, &WebEngineWallet::walletOpened, this, &WebEnginePart::updateWalletActions);
     }
 }
 
@@ -436,7 +432,7 @@ bool WebEnginePart::openUrl(const QUrl &_u)
             p->setSslInfo(sslInfo);
         }
     }
-    
+
     attemptInstallKIOSchemeHandler(u);
 
     // Set URL in KParts before emitting started; konq plugins rely on that.
@@ -510,7 +506,7 @@ void WebEnginePart::slotLoadFinished (bool ok)
     if (!ok || !m_doLoadFinishedActions)
         return;
 
-    slotWalletClosed();
+    resetWallet();
     m_doLoadFinishedActions = false;
 
     // If the document contains no <title> tag, then set it to the current url.
@@ -526,18 +522,9 @@ void WebEnginePart::slotLoadFinished (bool ok)
         // documents...
         slotUrlChanged(url);
     }
-    if (!Utils::isBlankUrl(url())) {
-        m_hasCachedFormData = false;
-        if (WebEngineSettings::self()->isNonPasswordStorableSite(url().host())) {
-            addWalletStatusBarIcon();
-        } 
-        else {
-// Attempt to fill the web form...
-            WebEngineWallet *wallet = page() ? page()->wallet() : nullptr;
-            if (wallet){
-                wallet->fillFormData(page());
-            }
-        }
+
+    if (m_wallet) {
+        m_wallet->detectAndFillPageForms(page());
     }
 
     bool pending = false;
@@ -587,7 +574,7 @@ void WebEnginePart::slotUrlChanged(const QUrl& url)
 
     // Do not update the location bar with about:blank
     if (!Utils::isBlankUrl(url)) {
-        //kDebug() << "Setting location bar to" << u.prettyUrl() << "current URL:" << this->url();
+        //qCDebug(WEBENGINEPART_LOG) << "Setting location bar to" << u.prettyUrl() << "current URL:" << this->url();
         emit m_browserExtension->setLocationBarUrl(u.toDisplayString());
     }
 }
@@ -613,7 +600,7 @@ void WebEnginePart::slotShowSecurity()
                     sslInfo.ciphers(),
                     sslInfo.usedChiperBits(),
                     sslInfo.supportedChiperBits(),
-                    KSslInfoDialog::errorsFromString(sslInfo.certificateErrors()));
+                    KSslInfoDialog::certificateErrorsFromString(sslInfo.certificateErrors()));
 
     dlg->open();
 }
@@ -635,7 +622,7 @@ void WebEnginePart::slotSaveFrameState(QWebFrame *frame, QWebHistoryItem *item)
     // slotRestoreFrameState.
     const QPoint scrollPos (frame->scrollPosition());
     if (!scrollPos.isNull()) {
-        // kDebug() << "Saving scroll position:" << scrollPos;
+        // qCDebug(WEBENGINEPART_LOG) << "Saving scroll position:" << scrollPos;
         item->setUserData(scrollPos);
     }
 }
@@ -679,7 +666,7 @@ void WebEnginePart::slotLinkHovered(const QString& _link)
         linkUrl.setUserName(QString());
         const QString link (linkUrl.toString());
 
-        if (QString::compare(scheme, QL1S("mailto"), Qt::CaseInsensitive) == 0) {
+        if (scheme == QL1S("mailto")) {
             message += i18nc("status bar text when hovering email links; looks like \"Email: xy@kde.org - CC: z@kde.org -BCC: x@kde.org - Subject: Hi translator\"", "Email: ");
 
             // Workaround: for QUrl's parsing deficiencies of "mailto:foo@bar.com".
@@ -693,7 +680,7 @@ void WebEnginePart::slotLinkHovered(const QString& _link)
 
             for(int i = 0; i < count; ++i) {
                 const QPair<QString, QString> queryItem (queryItems.at(i));
-                //kDebug() << "query: " << queryItem.first << queryItem.second;
+                //qCDebug(WEBENGINEPART_LOG) << "query: " << queryItem.first << queryItem.second;
                 if (queryItem.first.contains(QL1C('@')) && queryItem.second.isEmpty())
                     fields[QStringLiteral("to")] << queryItem.first;
                 if (QString::compare(queryItem.first, QL1S("to"), Qt::CaseInsensitive) == 0)
@@ -750,7 +737,7 @@ void WebEnginePart::slotSearchForText(const QString &text, bool backward)
     if (m_searchBar->caseSensitive())
         flags |= QWebEnginePage::FindCaseSensitively;
 
-    //kDebug() << "search for text:" << text << ", backward ?" << backward;
+    //qCDebug(WEBENGINEPART_LOG) << "search for text:" << text << ", backward ?" << backward;
     page()->findText(text, flags, [this](bool found) {
         m_searchBar->setFoundMatch(found);
     });
@@ -761,13 +748,13 @@ void WebEnginePart::slotShowSearchBar()
     if (!m_searchBar) {
         // Create the search bar...
         m_searchBar = new SearchBar(widget());
-        connect(m_searchBar, SIGNAL(searchTextChanged(QString,bool)),
-                this, SLOT(slotSearchForText(QString,bool)));
+        connect(m_searchBar, &SearchBar::searchTextChanged, this, &WebEnginePart::slotSearchForText);
 
-        actionCollection()->addAction(KStandardAction::FindNext, QStringLiteral("findnext"),
-                                      m_searchBar, SLOT(findNext()));
-        actionCollection()->addAction(KStandardAction::FindPrev, QStringLiteral("findprev"),
-                                      m_searchBar, SLOT(findPrevious()));
+        // This essentially duplicates the use of
+        // KActionCollection::addAction(KStandardAction::StandardAction actionType, const QObject *receiver, const char *member)
+        // with the Qt5 connect syntax.
+        KStandardAction::create(KStandardAction::FindNext, m_searchBar, &SearchBar::findNext, actionCollection());
+        KStandardAction::create(KStandardAction::FindPrev, m_searchBar, &SearchBar::findPrevious, actionCollection());
 
         QBoxLayout* lay = qobject_cast<QBoxLayout*>(widget()->layout());
         if (lay) {
@@ -798,29 +785,45 @@ void WebEnginePart::slotSelectionClipboardUrlPasted(const QUrl& selectedUrl, con
     emit m_browserExtension->openUrlRequest(selectedUrl);
 }
 
-void WebEnginePart::slotWalletClosed()
+void WebEnginePart::deleteStatusBarWalletLabel()
 {
-    if (!m_statusBarWalletLabel)
+    if (!m_statusBarWalletLabel) {
        return;
-
+    }
     m_statusBarExtension->removeStatusBarItem(m_statusBarWalletLabel);
     delete m_statusBarWalletLabel;
     m_statusBarWalletLabel = nullptr;
-    m_hasCachedFormData = false;
+}
+
+void WebEnginePart::resetWallet()
+{
+    deleteStatusBarWalletLabel();
+    updateWalletData({false, false, false});
+    updateWalletActions();
 }
 
 void WebEnginePart::slotShowWalletMenu()
 {
     QMenu *menu = new QMenu(nullptr);
+    auto addAction = [this, menu](const QString &name) {
+        QAction *a = actionCollection()->action(name);
+        if (a->isEnabled()) {
+            menu->addAction(a);
+        }
+    };
+    addAction("walletFillFormsNow");
+    addAction("walletCacheFormsNow");
 
-    if (m_webView && WebEngineSettings::self()->isNonPasswordStorableSite(m_webView->url().host()))
-      menu->addAction(i18n("&Allow password caching for this site"), this, SLOT(slotDeleteNonPasswordStorableSite()));
-
-    if (m_hasCachedFormData)
-      menu->addAction(i18n("Remove all cached passwords for this site"), this, SLOT(slotRemoveCachedPasswords()));
-
+    addAction("walletCustomizeFields");
+    addAction("walletRemoveCustomization");
     menu->addSeparator();
-    menu->addAction(i18n("&Close Wallet"), this, SLOT(slotWalletClosed()));
+
+    addAction("walletDisablePasswordCaching");
+    addAction("walletRemoveCachedData");
+    menu->addSeparator();
+
+    addAction("walletShowManager");
+    addAction("walletCloseWallet");
 
     KAcceleratorManager::manage(menu);
     menu->popup(QCursor::pos());
@@ -828,26 +831,34 @@ void WebEnginePart::slotShowWalletMenu()
 
 void WebEnginePart::slotLaunchWalletManager()
 {
-    QDBusInterface r(QStringLiteral("org.kde.kwalletmanager"), QStringLiteral("/kwalletmanager/MainWindow_1"));
-    if (r.isValid())
-        r.call(QDBus::NoBlock, QStringLiteral("show"));
-    else
-        KToolInvocation::startServiceByDesktopName(QStringLiteral("kwalletmanager_show"));
+    const KService::Ptr kwalletManager = KService::serviceByDesktopName(QStringLiteral("org.kde.kwalletmanager5"));
+    auto job = new KIO::ApplicationLauncherJob(kwalletManager);
+    job->start();
 }
 
-void WebEnginePart::slotDeleteNonPasswordStorableSite()
+void WebEnginePart::togglePasswordStorableState(bool on)
 {
-    if (m_webView)
-        WebEngineSettings::self()->removeNonPasswordStorableSite(m_webView->url().host());
+    if (!m_webView) {
+        return;
+    }
+    QString host = m_webView->url().host();
+    if (on) {
+        WebEngineSettings::self()->removeNonPasswordStorableSite(host);
+    } else {
+        WebEngineSettings::self()->addNonPasswordStorableSite(host);
+    }
+    updateWalletActions();
+    updateWalletStatusBarIcon();
 }
 
 void WebEnginePart::slotRemoveCachedPasswords()
 {
-    if (!page() || !page()->wallet())
+    if (!page() || !page()->wallet()) {
         return;
+    }
 
     page()->wallet()->removeFormData(page());
-    m_hasCachedFormData = false;
+    updateWalletData(WalletData::HasCachedData, false);
 }
 
 void WebEnginePart::slotSetTextEncoding(QTextCodec * codec)
@@ -886,44 +897,41 @@ void WebEnginePart::slotWindowCloseRequested()
     this->deleteLater();
 }
 
-void WebEnginePart::slotShowFeaturePermissionBar(QWebEnginePage::Feature feature)
+void WebEnginePart::slotShowFeaturePermissionBar(const QUrl &origin, QWebEnginePage::Feature feature)
 {
-    // FIXME: Allow multiple concurrent feature permission requests.
-    if (m_featurePermissionBar && m_featurePermissionBar->isVisible())
+    auto findExistingBar = [origin, feature](FeaturePermissionBar *bar) {
+        return bar->url() == origin && bar->feature() == feature;
+    };
+    auto found = std::find_if(m_permissionBars.constBegin(), m_permissionBars.constEnd(), findExistingBar);
+    if (found != m_permissionBars.constEnd()) {
         return;
-
-    if (!m_featurePermissionBar) {
-        m_featurePermissionBar = new FeaturePermissionBar(widget());
-
-        connect(m_featurePermissionBar, SIGNAL(permissionGranted(QWebEnginePage::Feature)),
-                this, SLOT(slotFeaturePermissionGranted(QWebEnginePage::Feature)));
-        connect(m_featurePermissionBar, SIGNAL(permissionDenied(QWebEnginePage::Feature)),
-                this, SLOT(slotFeaturePermissionDenied(QWebEnginePage::Feature)));
-        connect(m_passwordBar, SIGNAL(done()),
-                this, SLOT(slotSaveFormDataDone()));
-        QBoxLayout* lay = qobject_cast<QBoxLayout*>(widget()->layout());
-        if (lay)
-            lay->insertWidget(0, m_featurePermissionBar);
     }
-    m_featurePermissionBar->setFeature(feature);
-//     m_featurePermissionBar->setText(i18n("<html>Do you want to grant the site <b>%1</b> "
-//                                     "access to information about your current physical location?",
-//                                     url.host()));
-    m_featurePermissionBar->setText(i18n("<html>Do you want to grant the site "
-                                    "access to information about your current physical location?"));
-    m_featurePermissionBar->animatedShow();
+    FeaturePermissionBar *bar = new FeaturePermissionBar(widget());
+    m_permissionBars.append(bar);
+    auto policyLambda = [this, bar](QWebEnginePage::Feature feature, QWebEnginePage::PermissionPolicy policy) {
+        slotFeaturePolicyChosen(bar, feature, policy);
+    };
+    connect(bar, &FeaturePermissionBar::permissionPolicyChosen, this, policyLambda);
+    connect(bar, &FeaturePermissionBar::done, this, [this, bar](){deleteFeaturePermissionBar(bar);});
+    QBoxLayout* lay = qobject_cast<QBoxLayout*>(widget()->layout());
+    if (lay) {
+        lay->insertWidget(0, bar);
+    }
+    bar->setUrl(origin);
+    bar->setFeature(feature);
+    bar->animatedShow();
 }
 
-void WebEnginePart::slotFeaturePermissionGranted(QWebEnginePage::Feature feature)
+void WebEnginePart::slotFeaturePolicyChosen(FeaturePermissionBar* bar, QWebEnginePage::Feature feature, QWebEnginePage::PermissionPolicy policy)
 {
-    Q_ASSERT(m_featurePermissionBar && m_featurePermissionBar->feature() == feature);
-    page()->setFeaturePermission(page()->url(), feature, QWebEnginePage::PermissionGrantedByUser);
+    Q_ASSERT(bar && bar->feature() == feature);
+    page()->setFeaturePermission(bar->url(), feature, policy);
 }
 
-void WebEnginePart::slotFeaturePermissionDenied(QWebEnginePage::Feature feature)
+void WebEnginePart::deleteFeaturePermissionBar(FeaturePermissionBar *bar)
 {
-    Q_ASSERT(m_featurePermissionBar && m_featurePermissionBar->feature() == feature);
-    page()->setFeaturePermission(page()->url(), feature, QWebEnginePage::PermissionDeniedByUser);
+    m_permissionBars.removeOne(bar);
+    bar->deleteLater();
 }
 
 void WebEnginePart::slotSaveFormDataRequested (const QString& key, const QUrl& url)
@@ -943,12 +951,12 @@ void WebEnginePart::slotSaveFormDataRequested (const QString& key, const QUrl& u
             qCWarning(WEBENGINEPART_LOG) << "No m_wallet instance found! This should never happen!";
             return;
         }
-        connect(m_passwordBar, SIGNAL(saveFormDataAccepted(QString)),
-                m_wallet, SLOT(acceptSaveFormDataRequest(QString)));
-        connect(m_passwordBar, SIGNAL(saveFormDataRejected(QString)),
-                m_wallet, SLOT(rejectSaveFormDataRequest(QString)));
-        connect(m_passwordBar, SIGNAL(done()),
-                this, SLOT(slotSaveFormDataDone()));
+        m_passwordBar->setForms(m_wallet->pendingSaveData(key));
+        connect(m_passwordBar, &PasswordBar::saveFormDataAccepted,
+                m_wallet, &WebEngineWallet::acceptSaveFormDataRequest);
+        connect(m_passwordBar, &PasswordBar::saveFormDataRejected,
+                m_wallet, &WebEngineWallet::rejectSaveFormDataRequest);
+        connect(m_passwordBar, &PasswordBar::done, this, &WebEnginePart::slotSaveFormDataDone);
     }
 
     Q_ASSERT(m_passwordBar);
@@ -961,8 +969,9 @@ void WebEnginePart::slotSaveFormDataRequested (const QString& key, const QUrl& u
                                 url.host()));
 
     QBoxLayout* lay = qobject_cast<QBoxLayout*>(widget()->layout());
-    if (lay)
+    if (lay) {
         lay->insertWidget(0, m_passwordBar);
+    }
 
     m_passwordBar->animatedShow();
 }
@@ -977,24 +986,134 @@ void WebEnginePart::slotSaveFormDataDone()
         lay->removeWidget(m_passwordBar);
 }
 
-void WebEnginePart::addWalletStatusBarIcon ()
+void WebEnginePart::updateWalletStatusBarIcon ()
 {
-    if (m_statusBarWalletLabel) {
-        m_statusBarExtension->removeStatusBarItem(m_statusBarWalletLabel);
-    } else {
-        m_statusBarWalletLabel = new KUrlLabel(m_statusBarExtension->statusBar());
-        m_statusBarWalletLabel->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum));
-        m_statusBarWalletLabel->setUseCursor(false);
-        m_statusBarWalletLabel->setPixmap(QIcon::fromTheme(QStringLiteral("wallet-open")).pixmap(QSize(16,16)));
-        connect(m_statusBarWalletLabel, SIGNAL(leftClickedUrl()), SLOT(slotLaunchWalletManager()));
-        connect(m_statusBarWalletLabel, SIGNAL(rightClickedUrl()), SLOT(slotShowWalletMenu()));
+    if (m_walletData.hasForms) {
+        if (m_statusBarWalletLabel) {
+            m_statusBarExtension->removeStatusBarItem(m_statusBarWalletLabel);
+        } else {
+            m_statusBarWalletLabel = new KUrlLabel(m_statusBarExtension->statusBar());
+            m_statusBarWalletLabel->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum));
+            m_statusBarWalletLabel->setUseCursor(false);
+            connect(m_statusBarWalletLabel, QOverload<>::of(&KUrlLabel::leftClickedUrl), this, &WebEnginePart::slotLaunchWalletManager);
+            connect(m_statusBarWalletLabel, QOverload<>::of(&KUrlLabel::rightClickedUrl), this, &WebEnginePart::slotShowWalletMenu);
+        }
+        QIcon icon = QIcon::fromTheme(m_walletData.hasCachedData ? QStringLiteral("wallet-open") : QStringLiteral("wallet-closed"));
+        m_statusBarWalletLabel->setPixmap(icon.pixmap(QSize(16,16)));
+        m_statusBarExtension->addStatusBarItem(m_statusBarWalletLabel, 0, false);
+    } else if (m_statusBarWalletLabel) {
+        deleteStatusBarWalletLabel();
     }
-    m_statusBarExtension->addStatusBarItem(m_statusBarWalletLabel, 0, false);
 }
 
 void WebEnginePart::slotFillFormRequestCompleted (bool ok)
 {
-    if ((m_hasCachedFormData = ok))
-        addWalletStatusBarIcon();
+    updateWalletData(WalletData::HasCachedData, ok);
 }
 
+void WebEnginePart::exitFullScreen()
+{
+    page()->triggerAction(QWebEnginePage::ExitFullScreen);
+}
+
+void WebEnginePart::walletFinishedFormDetection(const QUrl& url, bool found, bool autoFillableFound)
+{
+    if (page() && page()->url() == url) {
+        updateWalletData({found, autoFillableFound});
+        updateWalletActions();
+        updateWalletStatusBarIcon();
+    }
+}
+
+void WebEnginePart::slotWalletSavedForms(const QUrl& url, bool success)
+{
+    if (success && url == this->url()) {
+        updateWalletData(WalletData::HasCachedData, true);
+    }
+}
+
+void WebEnginePart::createWalletActions()
+{
+    QAction *a = new QAction(i18nc("Fill the Forms with Data from KWallet", "&Fill forms now"), this);
+    a->setShortcut(QKeySequence("Ctrl+Shift+V"));
+    actionCollection()->addAction("walletFillFormsNow", a);
+    connect(a, &QAction::triggered, this, [this]{if(page() && m_wallet){m_wallet->detectAndFillPageForms(page());}});
+
+    a = new QAction(i18n("&Memorize Passwords in This Page Now"), this);
+    actionCollection()->addAction("walletCacheFormsNow", a);
+    connect(a, &QAction::triggered, this, [this]{if (page() && m_wallet){m_wallet->savePageDataNow(page());}});
+
+    a = new QAction(i18n("&Customize Fields to Memorize for This Page..."), this);
+    actionCollection()->addAction("walletCustomizeFields", a);
+    connect(a, &QAction::triggered, this, [this](){if (m_wallet){m_wallet->customizeFieldsToCache(page(), view());}});
+
+    a = new QAction(i18n("Remove Customized Memorization Settings for This Page"), this);
+    actionCollection()->addAction("walletRemoveCustomization", a);
+    connect(a, &QAction::triggered, this, [this](){m_wallet->removeCustomizationForPage(url());});
+
+    KToggleAction *ta = new KToggleAction (i18n("&Allow Password Caching for This Site"), this);
+    actionCollection()->addAction("walletDisablePasswordCaching", ta);
+    connect(ta, &QAction::triggered, this, &WebEnginePart::togglePasswordStorableState);
+
+    a = new QAction(i18n("Remove All Memorized Passwords for This Site"), this);
+    actionCollection()->addAction("walletRemoveCachedData", a);
+    connect(a, &QAction::triggered, this, &WebEnginePart::slotRemoveCachedPasswords);
+
+    a = new QAction(i18n("&Launch Wallet Manager"), this);
+    actionCollection()->addAction("walletShowManager", a);
+    connect(a, &QAction::triggered, this, &WebEnginePart::slotLaunchWalletManager);
+
+    a = new QAction(i18n("&Close Wallet"), this);
+    actionCollection()->addAction("walletCloseWallet", a);
+    connect(a, &QAction::triggered, this, &WebEnginePart::resetWallet);
+
+    updateWalletActions();
+}
+
+void WebEnginePart::updateWalletActions()
+{
+    bool enableCaching = m_webView && !WebEngineSettings::self()->isNonPasswordStorableSite(m_webView->url().host());
+    bool hasCustomForms = m_wallet && m_wallet->hasCustomizedCacheableForms(url());
+    actionCollection()->action("walletFillFormsNow")->setEnabled(enableCaching && m_wallet && m_walletData.hasCachedData);
+    actionCollection()->action("walletCacheFormsNow")->setEnabled(enableCaching && m_wallet && (m_walletData.hasAutoFillableForms || hasCustomForms));
+    actionCollection()->action("walletCustomizeFields")->setEnabled(enableCaching && m_walletData.hasForms);
+    actionCollection()->action("walletRemoveCustomization")->setEnabled(hasCustomForms);
+    QAction *a = actionCollection()->action("walletDisablePasswordCaching");
+    a->setChecked(enableCaching);
+    a->setEnabled(m_walletData.hasForms);
+    actionCollection()->action("walletRemoveCachedData")->setEnabled(m_walletData.hasCachedData);
+    actionCollection()->action("walletCloseWallet")->setEnabled(m_wallet && m_wallet->isOpen());
+}
+
+void WebEnginePart::updateWalletData(WebEnginePart::WalletData::Member which, bool status)
+{
+    switch (which) {
+        case WalletData::HasForms:
+            m_walletData.hasForms = status;
+            break;
+        case WalletData::HasAutofillableForms:
+            m_walletData.hasAutoFillableForms = status;
+            break;
+        case WalletData::HasCachedData:
+            m_walletData.hasCachedData = status;
+            break;
+    }
+    updateWalletActions();
+    updateWalletStatusBarIcon();
+}
+
+void WebEnginePart::updateWalletData(std::initializer_list<bool> data)
+{
+    Q_ASSERT(data.size() > 0 && data.size() < 4);
+    int size = data.size();
+    auto it = data.begin();
+    m_walletData.hasForms = it[0];
+    if (size > 1) {
+        m_walletData.hasAutoFillableForms = it[1];
+    }
+    if (size > 2) {
+        m_walletData.hasAutoFillableForms = it[2];
+    }
+    updateWalletActions();
+    updateWalletStatusBarIcon();
+}
