@@ -43,7 +43,6 @@ class FeaturePermissionBar;
 class KUrlLabel;
 class WebEngineBrowserExtension;
 class WebEngineWallet;
-class WebEngineErrorSchemeHandler;
 
 /**
  * A KPart wrapper for the QtWebEngine's browser rendering engine.
@@ -99,10 +98,13 @@ public:
      */
     void connectWebEnginePageSignals(WebEnginePage* page);
 
-    void slotShowFeaturePermissionBar(QWebEnginePage::Feature);
+    void slotShowFeaturePermissionBar(const QUrl &origin, QWebEnginePage::Feature);
 
     void setWallet(WebEngineWallet* wallet);
 
+public Q_SLOTS:
+    void exitFullScreen();
+
 protected:
     /**
      * Re-implemented for internal reasons. API remains unaffected.
@@ -133,39 +135,56 @@ private Q_SLOTS:
     void slotSelectionClipboardUrlPasted(const QUrl&, const QString&);
 
     void slotUrlChanged(const QUrl &);
-    void slotWalletClosed();
+    void resetWallet();
     void slotShowWalletMenu();
     void slotLaunchWalletManager();
-    void slotDeleteNonPasswordStorableSite();
+    void togglePasswordStorableState(bool on);
     void slotRemoveCachedPasswords();
     void slotSetTextEncoding(QTextCodec*);
     void slotSetStatusBarText(const QString& text);
     void slotWindowCloseRequested();
     void slotSaveFormDataRequested(const QString &, const QUrl &);
     void slotSaveFormDataDone();
+    void slotWalletSavedForms(const QUrl &url, bool success);
     void slotFillFormRequestCompleted(bool);
 
-    void slotFeaturePermissionGranted(QWebEnginePage::Feature);
-    void slotFeaturePermissionDenied(QWebEnginePage::Feature);
+    void slotFeaturePolicyChosen(FeaturePermissionBar *bar, QWebEnginePage::Feature feature, QWebEnginePage::PermissionPolicy policy);
+    void deleteFeaturePermissionBar(FeaturePermissionBar *bar);
+
+    void updateWalletStatusBarIcon();
+    void walletFinishedFormDetection(const QUrl &url, bool found, bool autoFillableFound);
+    void updateWalletActions();
 
 private:
     WebEnginePage* page();
     const WebEnginePage* page() const;
     static void initWebEngineUrlSchemes();
-    
+    void deleteStatusBarWalletLabel();
+
+    struct WalletData{
+        enum Member{HasForms, HasAutofillableForms, HasCachedData};
+        bool hasForms;
+        bool hasAutoFillableForms;
+        bool hasCachedData;
+    };
+    //Always use the following functions to change the values of m_walletData, as they automatically update the UI
+    void updateWalletData(WalletData::Member which, bool status);
+    void updateWalletData(std::initializer_list<bool> data);
+
     void attemptInstallKIOSchemeHandler(const QUrl &url);
-    
+
     void initActions();
+    void createWalletActions();
     void updateActions();
-    void addWalletStatusBarIcon();
 
     bool m_emitOpenUrlNotify;
-    bool m_hasCachedFormData;
+
+    WalletData m_walletData;
     bool m_doLoadFinishedActions;
     KUrlLabel* m_statusBarWalletLabel;
     SearchBar* m_searchBar;
     PasswordBar* m_passwordBar;
-    FeaturePermissionBar* m_featurePermissionBar;
+    QVector<FeaturePermissionBar*> m_permissionBars;
     WebEngineBrowserExtension* m_browserExtension;
     KParts::StatusBarExtension* m_statusBarExtension;
     WebEngineView* m_webView;
