@@ -21,7 +21,7 @@
 #ifndef WEBENGINEPARTFACTORY
 #define WEBENGINEPARTFACTORY
 
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 
 #include <QHash>
 
@@ -30,11 +30,11 @@ class QWidget;
 class WebEngineFactory : public KPluginFactory
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.KPluginFactory")
+    Q_PLUGIN_METADATA(IID KPluginFactory_iid FILE "webenginepart.json")
     Q_INTERFACES(KPluginFactory)
 public:
-    virtual ~WebEngineFactory();
-    QObject *create(const char* iface, QWidget *parentWidget, QObject *parent, const QVariantList& args, const QString &keyword) Q_DECL_OVERRIDE;
+    ~WebEngineFactory() override;
+    QObject *create(const char* iface, QWidget *parentWidget, QObject *parent, const QVariantList& args, const QString &keyword) override;
 
 private Q_SLOTS:
     void slotDestroyed(QObject* object);
