@@ -20,12 +20,7 @@
 
 #include "webenginepartkiohandler.h"
 
-#ifndef USE_QWEBENGINE_URL_SCHEME
-#include "webengineparthtmlembedder.h"
-#endif
-
 #include <QMimeDatabase>
-#include <QWebEngineUrlRequestJob>
 #include <QBuffer>
 #include <QtWebEngine/QtWebEngineVersion>
 
@@ -39,9 +34,6 @@ void WebEnginePartKIOHandler::requestStarted(QWebEngineUrlRequestJob *req)
 
 WebEnginePartKIOHandler::WebEnginePartKIOHandler(QObject* parent):
     QWebEngineUrlSchemeHandler(parent)
-#ifndef USE_QWEBENGINE_URL_SCHEME
-    , m_embedder(nullptr)
-#endif
 {
     connect(this, &WebEnginePartKIOHandler::ready, this, &WebEnginePartKIOHandler::sendReply);
 }
@@ -89,15 +81,7 @@ void WebEnginePartKIOHandler::embedderFinished(const QString& html)
 
 void WebEnginePartKIOHandler::processSlaveOutput()
 {
-#ifdef USE_QWEBENGINE_URL_SCHEME
     emit ready();
-#else
-    if (m_mimeType.inherits("text/html") || m_mimeType.inherits("application/xhtml+xml")) {
-        htmlEmbedder()->startEmbedding(m_data, m_mimeType.name());
-    } else {
-        emit ready();
-    }
-#endif
 }
 
 void WebEnginePartKIOHandler::kioJobFinished(KIO::StoredTransferJob* job)
@@ -108,14 +92,3 @@ void WebEnginePartKIOHandler::kioJobFinished(KIO::StoredTransferJob* job)
     m_mimeType = QMimeDatabase().mimeTypeForData(m_data);
     processSlaveOutput();
 }
-
-#ifndef USE_QWEBENGINE_URL_SCHEME
-WebEnginePartHtmlEmbedder * WebEnginePartKIOHandler::htmlEmbedder()
-{
-    if (!m_embedder) {
-        m_embedder = new WebEnginePartHtmlEmbedder(this);
-        connect(htmlEmbedder(), &WebEnginePartHtmlEmbedder::finished, this, &WebEnginePartKIOHandler::embedderFinished);
-    }
-    return m_embedder;
-}
-#endif
